@@ -2,6 +2,12 @@
 grdcontour - Make contour map using a grid.
 """
 
+from collections.abc import Sequence
+from typing import Literal
+
+import xarray as xr
+from pygmt._typing import PathLike
+from pygmt.alias import AliasSystem
 from pygmt.clib import Session
 from pygmt.helpers import (
     build_arg_list,
@@ -22,29 +28,39 @@ __doctest_skip__ = ["grdcontour"]
     B="frame",
     C="levels",
     G="label_placement",
-    J="projection",
     L="limit",
     Q="cut",
-    R="region",
     S="resample",
-    V="verbose",
     W="pen",
     l="label",
-    c="panel",
     f="coltypes",
     p="perspective",
-    t="transparency",
 )
-@kwargs_to_strings(R="sequence", L="sequence", c="sequence_comma", p="sequence")
-def grdcontour(self, grid, **kwargs):
+@kwargs_to_strings(L="sequence", p="sequence")
+def grdcontour(
+    self,
+    grid: PathLike | xr.DataArray,
+    projection: str | None = None,
+    region: Sequence[float | str] | str | None = None,
+    verbose: Literal["quiet", "error", "warning", "timing", "info", "compat", "debug"]
+    | bool = False,
+    panel: int | tuple[int, int] | bool = False,
+    transparency: float | None = None,
+    **kwargs,
+):
     r"""
     Make contour map using a grid.
 
     Takes a grid file name or an :class:`xarray.DataArray` object as input.
 
-    Full option list at :gmt-docs:`grdcontour.html`
+    Full GMT docs at :gmt-docs:`grdcontour.html`.
 
     {aliases}
+       - J = projection
+       - R = region
+       - V = verbose
+       - c = panel
+       - t = transparency
 
     Parameters
     ----------
@@ -136,7 +152,7 @@ def grdcontour(self, grid, **kwargs):
     >>> # Show the plot
     >>> fig.show()
     """
-    kwargs = self._preprocess(**kwargs)
+    self._activate_figure()
 
     # Specify levels for the annotation and levels parameters.
     # One level is converted to a string with a trailing comma to separate it from
@@ -149,8 +165,17 @@ def grdcontour(self, grid, **kwargs):
             else:  # Multiple levels
                 kwargs[arg] = ",".join(f"{item}" for item in kwargs[arg])
 
+    aliasdict = AliasSystem().add_common(
+        J=projection,
+        R=region,
+        V=verbose,
+        c=panel,
+        t=transparency,
+    )
+    aliasdict.merge(kwargs)
+
     with Session() as lib:
         with lib.virtualfile_in(check_kind="raster", data=grid) as vingrd:
             lib.call_module(
-                module="grdcontour", args=build_arg_list(kwargs, infile=vingrd)
+                module="grdcontour", args=build_arg_list(aliasdict, infile=vingrd)
             )
