@@ -2,6 +2,12 @@
 grdview - Create 3-D perspective image or surface mesh from a grid.
 """
 
+from collections.abc import Sequence
+from typing import Literal
+
+import xarray as xr
+from pygmt._typing import PathLike
+from pygmt.alias import AliasSystem
 from pygmt.clib import Session
 from pygmt.helpers import build_arg_list, fmt_docstring, kwargs_to_strings, use_alias
 
@@ -10,8 +16,6 @@ __doctest_skip__ = ["grdview"]
 
 @fmt_docstring
 @use_alias(
-    R="region",
-    J="projection",
     Jz="zscale",
     JZ="zsize",
     B="frame",
@@ -23,15 +27,22 @@ __doctest_skip__ = ["grdview"]
     Wm="meshpen",
     Wf="facadepen",
     I="shading",
-    V="verbose",
-    c="panel",
     f="coltypes",
     n="interpolation",
     p="perspective",
-    t="transparency",
 )
-@kwargs_to_strings(R="sequence", c="sequence_comma", p="sequence")
-def grdview(self, grid, **kwargs):
+@kwargs_to_strings(p="sequence")
+def grdview(
+    self,
+    grid: PathLike | xr.DataArray,
+    projection: str | None = None,
+    region: Sequence[float | str] | str | None = None,
+    verbose: Literal["quiet", "error", "warning", "timing", "info", "compat", "debug"]
+    | bool = False,
+    panel: int | tuple[int, int] | bool = False,
+    transparency: float | None = None,
+    **kwargs,
+):
     r"""
     Create 3-D perspective image or surface mesh from a grid.
 
@@ -41,9 +52,14 @@ def grdview(self, grid, **kwargs):
     set on top of a surface, plotting of contours on top of the surface, and apply
     artificial illumination based on intensities provided in a separate grid file.
 
-    Full option list at :gmt-docs:`grdview.html`
+    Full GMT docs at :gmt-docs:`grdview.html`.
 
     {aliases}
+       - J = projection
+       - R = region
+       - V = verbose
+       - c = panel
+       - t = transparency
 
     Parameters
     ----------
@@ -138,15 +154,25 @@ def grdview(self, grid, **kwargs):
     >>> # Show the plot
     >>> fig.show()
     """
-    kwargs = self._preprocess(**kwargs)
+    self._activate_figure()
+
+    aliasdict = AliasSystem().add_common(
+        J=projection,
+        R=region,
+        V=verbose,
+        c=panel,
+        t=transparency,
+    )
+    aliasdict.merge(kwargs)
+
     with Session() as lib:
         with (
             lib.virtualfile_in(check_kind="raster", data=grid) as vingrd,
             lib.virtualfile_in(
-                check_kind="raster", data=kwargs.get("G"), required_data=False
+                check_kind="raster", data=kwargs.get("G"), required=False
             ) as vdrapegrid,
         ):
-            kwargs["G"] = vdrapegrid
+            aliasdict["G"] = vdrapegrid
             lib.call_module(
-                module="grdview", args=build_arg_list(kwargs, infile=vingrd)
+                module="grdview", args=build_arg_list(aliasdict, infile=vingrd)
             )
