@@ -6,6 +6,8 @@ from typing import Literal
 
 import numpy as np
 import pandas as pd
+from pygmt._typing import PathLike, TableLike
+from pygmt.alias import AliasSystem
 from pygmt.clib import Session
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
@@ -29,19 +31,20 @@ from pygmt.helpers import (
     Q="unit",
     S="sort",
     T="pole",
-    V="verbose",
     W="width",
     Z="ellipse",
     f="coltypes",
 )
 @kwargs_to_strings(E="sequence", L="sequence", T="sequence", W="sequence", C="sequence")
 def project(
-    data=None,
+    data: PathLike | TableLike | None = None,
     x=None,
     y=None,
     z=None,
     output_type: Literal["pandas", "numpy", "file"] = "pandas",
-    outfile: str | None = None,
+    outfile: PathLike | None = None,
+    verbose: Literal["quiet", "error", "warning", "timing", "info", "compat", "debug"]
+    | bool = False,
     **kwargs,
 ) -> pd.DataFrame | np.ndarray | None:
     r"""
@@ -92,8 +95,8 @@ def project(
 
     Flat Earth (Cartesian) coordinate transformations can also be made. Set
     ``flat_earth=True`` and remember that azimuth is clockwise from North (the
-    y axis), NOT the usual cartesian theta, which is counterclockwise from the
-    x axis. azimuth = 90 - theta.
+    y-axis), NOT the usual cartesian theta, which is counterclockwise from the
+    x-axis. azimuth = 90 - theta.
 
     No assumptions are made regarding the units for
     :math:`x, y, r, s, p, q, dist, l_{{min}}, l_{{max}}, w_{{min}}, w_{{max}}`.
@@ -106,13 +109,14 @@ def project(
     back-azimuths or azimuths are better done using :gmt-docs:`mapproject` as
     project is strictly spherical.
 
-    Full option list at :gmt-docs:`project.html`
+    Full GMT docs at :gmt-docs:`project.html`.
 
     {aliases}
+       - V = verbose
 
     Parameters
     ----------
-    data : str, {table-like}
+    data
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
         providing a file name to an ASCII data table, a 2-D
         {table-classes}.
@@ -237,6 +241,11 @@ def project(
     if output_type == "pandas" and kwargs.get("G") is not None:
         column_names = list("rsp")
 
+    aliasdict = AliasSystem().add_common(
+        V=verbose,
+    )
+    aliasdict.merge(kwargs)
+
     with Session() as lib:
         with (
             lib.virtualfile_in(
@@ -245,14 +254,14 @@ def project(
                 x=x,
                 y=y,
                 z=z,
-                required_z=False,
-                required_data=False,
+                mincols=2,
+                required=False,
             ) as vintbl,
             lib.virtualfile_out(kind="dataset", fname=outfile) as vouttbl,
         ):
             lib.call_module(
                 module="project",
-                args=build_arg_list(kwargs, infile=vintbl, outfile=vouttbl),
+                args=build_arg_list(aliasdict, infile=vintbl, outfile=vouttbl),
             )
         return lib.virtualfile_to_dataset(
             vfname=vouttbl,
