@@ -2,8 +2,10 @@
 tilemap - Plot XYZ tile maps.
 """
 
+from collections.abc import Sequence
 from typing import Literal
 
+from pygmt.alias import Alias, AliasSystem
 from pygmt.clib import Session
 from pygmt.datasets.tile_map import load_tile_map
 from pygmt.enums import GridType
@@ -20,26 +22,26 @@ except ImportError:
     B="frame",
     E="dpi",
     I="shading",
-    J="projection",
-    M="monochrome",
-    N="no_clip",
     Q="nan_transparent",
-    # R="region",
-    V="verbose",
-    c="panel",
     p="perspective",
-    t="transparency",
 )
-@kwargs_to_strings(c="sequence_comma", p="sequence")  # R="sequence",
-def tilemap(
+@kwargs_to_strings(p="sequence")
+def tilemap(  # noqa: PLR0913
     self,
-    region: list,
+    region: Sequence[float],
     zoom: int | Literal["auto"] = "auto",
     source: TileProvider | str | None = None,
     lonlat: bool = True,
     wait: int = 0,
     max_retries: int = 2,
     zoom_adjust: int | None = None,
+    monochrome: bool = False,
+    no_clip: bool = False,
+    projection: str | None = None,
+    verbose: Literal["quiet", "error", "warning", "timing", "info", "compat", "debug"]
+    | bool = False,
+    panel: int | tuple[int, int] | bool = False,
+    transparency: float | None = None,
     **kwargs,
 ):
     r"""
@@ -56,6 +58,12 @@ def tilemap(
     provide Spherical Mercator (EPSG:3857) coordinates to the ``region`` parameter.
 
     {aliases}
+       - J = projection
+       - M = monochrome
+       - N = no_clip
+       - V = verbose
+       - c = panel
+       - t = transparency
 
     Parameters
     ----------
@@ -102,14 +110,10 @@ def tilemap(
     zoom_adjust
         The amount to adjust a chosen zoom level if it is chosen automatically. Values
         outside of -1 to 1 are not recommended as they can lead to slow execution.
-
-        .. note::
-           The ``zoom_adjust`` parameter requires ``contextily>=1.5.0``.
-
     kwargs : dict
         Extra keyword arguments to pass to :meth:`pygmt.Figure.grdimage`.
     """
-    kwargs = self._preprocess(**kwargs)
+    self._activate_figure()
 
     raster = load_tile_map(
         region=region,
@@ -124,13 +128,25 @@ def tilemap(
     if lonlat:
         raster.gmt.gtype = GridType.GEOGRAPHIC
 
-    # Only set region if no_clip is None or False, so that plot is clipped to exact
-    # bounding box region
-    if kwargs.get("N") in {None, False}:
-        kwargs["R"] = "/".join(str(coordinate) for coordinate in region)
+    # If no_clip is not True, set region to None so that plot is clipped to exact
+    # bounding box region.
+    if kwargs.get("N", no_clip) not in {None, False}:
+        region = None  # type: ignore[assignment]
+
+    aliasdict = AliasSystem(
+        M=Alias(monochrome, name="monochrome"),
+        N=Alias(no_clip, name="no_clip"),
+    ).add_common(
+        J=projection,
+        R=region,
+        V=verbose,
+        c=panel,
+        t=transparency,
+    )
+    aliasdict.merge(kwargs)
 
     with Session() as lib:
         with lib.virtualfile_in(check_kind="raster", data=raster) as vingrd:
             lib.call_module(
-                module="grdimage", args=build_arg_list(kwargs, infile=vingrd)
+                module="grdimage", args=build_arg_list(aliasdict, infile=vingrd)
             )
